pub struct Beatmap {Show 37 fields
pub approval_status: ApprovalStatus,
pub submit_date: OffsetDateTime,
pub approved_date: Option<OffsetDateTime>,
pub last_update: OffsetDateTime,
pub artist: String,
pub title: String,
pub version: String,
pub beatmap_id: u32,
pub beatmapset_id: u32,
pub bpm: f32,
pub creator: String,
pub creator_id: u32,
pub stars: f32,
pub stars_aim: Option<f32>,
pub stars_speed: Option<f32>,
pub diff_cs: f32,
pub diff_od: f32,
pub diff_ar: f32,
pub diff_hp: f32,
pub seconds_drain: u32,
pub seconds_total: u32,
pub source: String,
pub genre: Genre,
pub language: Language,
pub mode: GameMode,
pub tags: String,
pub favourite_count: u32,
pub rating: f32,
pub playcount: u32,
pub passcount: u32,
pub count_circle: u32,
pub count_slider: u32,
pub count_spinner: u32,
pub max_combo: Option<u32>,
pub download_unavailable: bool,
pub audio_unavailable: bool,
pub file_md5: Option<String>,
}Expand description
Beatmap struct retrieved from the /api/get_beatmaps endpoint.
Fields
approval_status: ApprovalStatussubmit_date: OffsetDateTimeapproved_date: Option<OffsetDateTime>last_update: OffsetDateTimeartist: Stringtitle: Stringversion: Stringbeatmap_id: u32beatmapset_id: u32bpm: f32creator: Stringcreator_id: u32stars: f32stars_aim: Option<f32>stars_speed: Option<f32>diff_cs: f32diff_od: f32diff_ar: f32diff_hp: f32seconds_drain: u32seconds_total: u32source: Stringgenre: Genrelanguage: Languagemode: GameModefavourite_count: u32rating: f32playcount: u32passcount: u32count_circle: u32count_slider: u32count_spinner: u32max_combo: Option<u32>file_md5: Option<String>Implementations
Sourceimpl Beatmap
impl Beatmap
Sourcepub fn get_creator<'o>(&self, osu: &'o Osu) -> GetUser<'o> ⓘ
pub fn get_creator<'o>(&self, osu: &'o Osu) -> GetUser<'o> ⓘ
Retrieve the creator of the beatmap from the API.
Be sure to specify GameMode if necessary, defaults to Osu.
Sourcepub fn get_global_leaderboard<'o>(&self, osu: &'o Osu) -> GetScores<'o> ⓘ
pub fn get_global_leaderboard<'o>(&self, osu: &'o Osu) -> GetScores<'o> ⓘ
Retrieve the global top scores of the beatmap from the API. Amount ranges from 1 to 100, defaults to 50.
Sourcepub fn count_objects(&self) -> u32
pub fn count_objects(&self) -> u32
Count all circles, sliders, and spinners of the beatmap